pub struct Stop {
pub function_code: FunctionCode,
pub location_identification: Option<Box<Location>>,
pub arrival_time: Option<String>,
pub departure_time: Option<String>,
}Expand description
Stop : Contractual or operational port or point relevant to the movement of the cargo.
Fields
function_code: FunctionCodeProvide the function code.
location_identification: Option<Box<Location>>arrival_time: Option<String>Date and time of the arrival of the cargo.
departure_time: Option<String>Date and time of the departure of the cargo.
Implementations